.. _ref-example_repos:

Example repositories
====================

 * A full demo based on the public CMS tutorial using 2012 data: `<https://github.com/FAST-HEP/fast_cms_public_tutorial>`_

Related Presentations
---------------------
1. IRIS-HEP, 4th March 2019: `<https://indico.cern.ch/event/802182/contributions/3334624/>`_
2. Analysis Descrition Languages for the LHC, 7th May 2019: `<https://indico.cern.ch/event/769263/contributions/3406084/>`_
